fnss.topologies.topology.DirectedTopology.reverse — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.DirectedTopology.reverse

`DirectedTopology.` `reverse`(copy=True)

  Return the reverse of the graph.

  The reverse is a graph with the same nodes and edges but with the directions of the edges reversed.

  Parameters : | copy : bool optional (default=True) If True, return a new DiGraph holding the reversed edges. If False, reverse the reverse graph is created using the original graph (this changes the original graph).

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »